==> opensaml-messaging-impl-3.4.5-sources.jar: org/opensaml/messaging/handler/impl/CheckExpectedIssuer.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.messaging.handler.impl;

import java.util.Objects;

import javax.annotation.Nonnull;

import net.shibboleth.utilities.java.support.annotation.constraint.NonnullAfterInit;
import net.shibboleth.utilities.java.support.component.ComponentInitializationException;
import net.shibboleth.utilities.java.support.component.ComponentSupport;
import net.shibboleth.utilities.java.support.logic.Constraint;

import org.opensaml.messaging.context.MessageContext;
import org.opensaml.messaging.handler.AbstractMessageHandler;
import org.opensaml.messaging.handler.MessageHandlerException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.base.Function;

/**
 * Message handler that checks that a message context has an issuer.
 */
public final class CheckExpectedIssuer extends AbstractMessageHandler {
    
    /** Logger. */
    private Logger log = LoggerFactory.getLogger(CheckExpectedIssuer.class);

    /** Strategy used to look up the issuer associated with the message context. */
    @NonnullAfterInit private Function<MessageContext,String> issuerLookupStrategy;
    
    /** Strategy used to look up the expected issuer associated with the message context. */
    @NonnullAfterInit private Function<MessageContext,String> expectedIssuerLookupStrategy;
    
    /**
     * Set the strategy used to look up the issuer associated with the message context.
     * 
     * @param strategy lookup strategy
     */
    public void setIssuerLookupStrategy(@Nonnull final Function<MessageContext,String> strategy) {
        ComponentSupport.ifInitializedThrowUnmodifiabledComponentException(this);

        issuerLookupStrategy = Constraint.isNotNull(strategy, "Message context issuer lookup strategy cannot be null");
    }
    
    /**
     * Set the strategy used to look up the expected issuer associated with the message context.
     * 
     * @param strategy lookup strategy
     */
    public void setExpectedIssuerLookupStrategy(@Nonnull final Function<MessageContext,String> strategy) {
        ComponentSupport.ifInitializedThrowUnmodifiabledComponentException(this);

        expectedIssuerLookupStrategy = Constraint.isNotNull(strategy, 
                "Message context expected issuer lookup strategy cannot be null");
    }
    
    /** {@inheritDoc} */
    @Override
    protected void doInitialize() throws ComponentInitializationException {
        super.doInitialize();
        
        if (issuerLookupStrategy == null) {
            throw new ComponentInitializationException(
                    "Message context issuer lookup strategy cannot be null");
        }
        if (expectedIssuerLookupStrategy == null) {
            throw new ComponentInitializationException(
                    "Message context expected issuer lookup strategy cannot be null");
        }
    }

    /** {@inheritDoc} */
    @Override
    protected void doInvoke(@Nonnull final MessageContext messageContext) throws MessageHandlerException {
        final String issuer = issuerLookupStrategy.apply(messageContext);
        if (issuer == null) {
            throw new MessageHandlerException("Message context did not contain an issuer");
        }
        
        final String expectedIssuer = expectedIssuerLookupStrategy.apply(messageContext);
        if (expectedIssuer == null) {
            throw new MessageHandlerException("Message context did not contain an expected issuer");
        }
        
        log.debug("Saw issuer '{}', expected issuer '{}'", issuer, expectedIssuer);
        
        if (!Objects.equals(issuer, expectedIssuer)) {
            throw new MessageHandlerException("Message context issuer did not match expected issuer");
        }
    }
    
}

==> opensaml-messaging-impl-4.1.1-sources.jar: org/opensaml/messaging/handler/impl/CheckExpectedIssuer.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.messaging.handler.impl;

import java.util.Objects;
import java.util.function.Function;

import javax.annotation.Nonnull;

import net.shibboleth.utilities.java.support.annotation.constraint.NonnullAfterInit;
import net.shibboleth.utilities.java.support.component.ComponentInitializationException;
import net.shibboleth.utilities.java.support.component.ComponentSupport;
import net.shibboleth.utilities.java.support.logic.Constraint;

import org.opensaml.messaging.context.MessageContext;
import org.opensaml.messaging.handler.AbstractMessageHandler;
import org.opensaml.messaging.handler.MessageHandlerException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Message handler that checks that a message context has an issuer.
 */
public final class CheckExpectedIssuer extends AbstractMessageHandler {
    
    /** Logger. */
    @Nonnull private Logger log = LoggerFactory.getLogger(CheckExpectedIssuer.class);

    /** Strategy used to look up the issuer associated with the message context. */
    @NonnullAfterInit private Function<MessageContext,String> issuerLookupStrategy;
    
    /** Strategy used to look up the expected issuer associated with the message context. */
    @NonnullAfterInit private Function<MessageContext,String> expectedIssuerLookupStrategy;
    
    /**
     * Set the strategy used to look up the issuer associated with the message context.
     * 
     * @param strategy lookup strategy
     */
    public void setIssuerLookupStrategy(@Nonnull final Function<MessageContext,String> strategy) {
        ComponentSupport.ifInitializedThrowUnmodifiabledComponentException(this);

        issuerLookupStrategy = Constraint.isNotNull(strategy, "Message context issuer lookup strategy cannot be null");
    }
    
    /**
     * Set the strategy used to look up the expected issuer associated with the message context.
     * 
     * @param strategy lookup strategy
     */
    public void setExpectedIssuerLookupStrategy(@Nonnull final Function<MessageContext,String> strategy) {
        ComponentSupport.ifInitializedThrowUnmodifiabledComponentException(this);

        expectedIssuerLookupStrategy = Constraint.isNotNull(strategy, 
                "Message context expected issuer lookup strategy cannot be null");
    }
    
    /** {@inheritDoc} */
    @Override
    protected void doInitialize() throws ComponentInitializationException {
        super.doInitialize();
        
        if (issuerLookupStrategy == null) {
            throw new ComponentInitializationException(
                    "Message context issuer lookup strategy cannot be null");
        }
        if (expectedIssuerLookupStrategy == null) {
            throw new ComponentInitializationException(
                    "Message context expected issuer lookup strategy cannot be null");
        }
    }

    /** {@inheritDoc} */
    @Override
    protected void doInvoke(@Nonnull final MessageContext messageContext) throws MessageHandlerException {
        final String issuer = issuerLookupStrategy.apply(messageContext);
        if (issuer == null) {
            throw new MessageHandlerException("Message context did not contain an issuer");
        }
        
        final String expectedIssuer = expectedIssuerLookupStrategy.apply(messageContext);
        if (expectedIssuer == null) {
            throw new MessageHandlerException("Message context did not contain an expected issuer");
        }
        
        log.debug("Saw issuer '{}', expected issuer '{}'", issuer, expectedIssuer);
        
        if (!Objects.equals(issuer, expectedIssuer)) {
            throw new MessageHandlerException("Message context issuer did not match expected issuer");
        }
    }
    
}
